@@ -2,7 +2,7 @@
 #
 # Author: Yipeng Sun <syp at umd dot edu>
 # License: BSD 2-clause
-# Last Change: Wed Sep 04, 2019 at 05:48 PM -0400
+# Last Change: Wed Sep 09, 2020 at 04:53 AM +0800
 
 import os
 import pytest
@@ -23,11 +23,11 @@ def default_Loader():
 
 def test_NestedYAMLLoader_values(default_Loader):
     result = default_Loader
-    assert result['ATuple']['rename'] == {k: k.lower()
-                                          for k in ['Y_PT', 'Y_PX', 'Y_PY',
-                                                    'Y_PZ']}
+    assert result['rename'] == {
+        k: k.lower() for k in ['Y_PT', 'Y_PX', 'Y_PY', 'Y_PZ', 'b0_PE']}
 
 
 def test_NestedYAMLLoader_subfile_values(default_Loader):
     result = default_Loader
-    assert result['YetAnotherTuple']['drop'] == ['Y_OWNPV_COV_', 'Y_OWNPV_P.*']
+    assert result['output']['YetAnotherTuple']['drop'] == [
+        'Y_OWNPV_COV_', 'Y_OWNPV_P.*']
